clear all
close all
clc

%% TABLE OF CONTENT
% 1. Import Video
% 2. Calibration 
% 3. Line Intensity Plot
% 4. Surface Intensity Plot

% Remark: This script is written for the experents recorded at 125 fps
% Remark: The recording have a 1264x1984 resolution

%% 1. Import Video

vid = VideoReader('D:\NTNU\10. Semester - MASTER\Spiral IDT\15042023\120MHz-Exp45_15042023_120MHz_2uL_7ump_conc_1_5_100mW_4xMag_125fps.mp4')

%% 2. Calibration

% AOS camera:
path = 'C:\Users\bjornmq\OneDrive - NTNU\10. Semester NTNU - Master TEP4926\05 Experimenter\Calibration_Images_14032023\FC_4xMag_500umGrid_14032023.png';

% PHOTRON High speed camera:
%cal_image = imread('C:\Users\bjornmq\OneDrive - NTNU\10. Semester NTNU - Master TEP4926\05 Experimenter\Calibration 500um HighSpeedCamera.tif'); 

ratio = Calibration(path) % um/px ratio

%%  3. Line Intensity Plot

FR = vid.FrameRate;
time_stap = 846;       % INPUT % Spesify timeframe for analysis
pretime = 46*FR/125;   % INPUT % Spesify start time when the SAW is initiated into the systen 
frame = read(vid,FR*time_stap);

% OPTIONAL % Adjusting illuminstion 
% frame = rgb2gray(frame);
%f rame = frame * 1.3;

% Mask ROI (Region Of Interest)
centre = [1000 643];
axis = [868 848];
Image = MaskedImage(frame, centre, axis);

time = vid.CurrentTime;  
img = imcomplement(Image);
figure(2)

ana_line = 950;          % INPUT % analytical line: define line to examine the intensity 120 MHz Exp45 60 sec

intensity = img(:, ana_line); % calculate the intensity along a vertical analystical line
%intensity = img(ana_line, :); % calculate the intensity along a horisontal analytical line 

% ------ FOR 2 analytical lines --------------
%ana_line2 = 520;                % For second horisontal analytical line
%intensity2 = img(ana_line2, :); % For second horisontal analytical line
%ana_line2 = 1500;               % For second vertical analytical line
%intensity2 = img(:, ana_line2); % For second vertical analytical line

TitleInputs = {'interpreter','latex','fontsize',17};
AxisInputs = {'interpreter','latex','fontsize',90};


% ---------- PLOT LINE INTENSIT PLOT --------------- %
figure3 = figure('Name','Intensity plot','Position',[40 40 1500 1500]);

plot(flip(intensity),'LineWidth',1.2)   % Ploting the intensity along a vertical analytical line
%plot(intensity,'LineWidth',1.2)        % Ploting the intensity along a horisontal analytical line
hold on

%plot(intensity2,'LineWidth',1.2)        % Ploting the second intensity along a horisontal analytical line
%plot(flip(intensity2),'LineWidth',1.2)  % Ploting the second intensity along a vertical analytical line

ax=gca;
ax.FontSize = 50;

xlim([0 1264]) % ana_line in the vertical direction
%xlim([0 1984])  % ana_line in the horisontal direction


xticklabels(0:round(500*ratio,0):round(1264*ratio,0))    % ana_line in the vertical direction
%xticklabels(0:round(500*ratio,0):round(1984*ratio,0))   % ana_line in the horisontaly direction

xlabel('Distance y [um]', AxisInputs{:})         % ana_line in the vertical direction
%xlabel('Distance x [um]', AxisInputs{:})        % ana_line in the horisontaly direction
ylabel('Intensity [a.u]', AxisInputs{:})
%title('Intensity', TitleInputs{:})              % OPTIONAL: Title 


% --------- PLOT DROPLET AND THE ANALYTICAL LINE ------------------- %
figure4 = figure('Name','Intensity plot droplet line','Position',[0 0 1500 1500]);
imshow(Image)%,title("Frame at timestep "+ num2str(time/5-pretime) +" s",TitleInputs{:})
hold on

plot([ana_line ana_line],[1 1264],'LineWidth',2)    % ana_line in the vertical direction
%plot([1 1984],[ana_line ana_line],'LineWidth',2)   % ana_line in the horisontaly direction

%plot([1 1984],[ana_line2 ana_line2],'LineWidth',2)   % second ana_line in the vertical direction
%plot([ana_line2 ana_line2],[1 1264],'LineWidth',2)   % second ana_line in the horisontal direction
hold off

%% 4. Surface Intensity Plot

FR = vid.FrameRate;
time_stap = 846; % seconds      As described above
pretime = 46*FR/125; %sec       As described above
frame = read(vid,FR*time_stap);

% OPTIONAL % As described above 
%frame = rgb2gray(frame);
%frame = frame * 1.3;

% Mask ROI
centre = [1000 643];
axis = [868 848];
Image = MaskedImage(frame, centre, axis);

t = vid.CurrentTime;   
Image = imcomplement(Image);
    
x = (1:1984);
[xx, yy]=meshgrid(1:1984,1:1264); 
    
int2 = [];
for X = x
    inten = Image(:,X); % Get th intensity
    int2 = [int2, inten];
end
    
TitleInputs = {'interpreter','latex','fontsize',17};
AxisInputs = {'interpreter','latex','fontsize',90};


% ----- PLOT SURFACE INTENSITY PLOT ---- %
figure1 = figure('Name','3D intensity surface plot','Position',[0 0 1500 1500]);
s = surf(xx*ratio,flip(yy*ratio),int2);
hold on
ax=gca;
ax.FontSize = 50;
ylim([0 1264*ratio])
xlim([0 1984*ratio])
%contourcbar
s.EdgeColor = 'none';
xlabel('x [um]',AxisInputs{:})
ylabel('y [um]',AxisInputs{:})
zlabel('Intensity [a.u]',AxisInputs{:})

%title("Inensity surface plot at timestep "+ num2str(t/5-pretime) +" s",TitleInputs{:}) 

